@@ -7,17 +7,17 @@ import json
 import os
 import tempfile
 import zipfile
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional
 
-from onefuzztypes.enums import OS, ContainerType, TaskState
+from onefuzztypes.enums import OS, ContainerType
 from onefuzztypes.models import Job, NotificationConfig
 from onefuzztypes.primitives import Container, Directory, File
 
-from onefuzz.backend import wait
+from ..job_templates.job_monitor import JobMonitor
 
 ELF_MAGIC = b"\x7fELF"
 DEFAULT_LINUX_IMAGE = "Canonical:UbuntuServer:18.04-LTS:latest"
-DEFAULT_WINDOWS_IMAGE = "MicrosoftWindowsDesktop:Windows-10:rs5-pro:latest"
+DEFAULT_WINDOWS_IMAGE = "MicrosoftWindowsDesktop:Windows-10:20h2-pro:latest"
 
 
 class StoppedEarly(Exception):
@@ -71,7 +71,7 @@ class JobHelper:
         self.project = project
         self.name = name
         self.build = build
-        self.to_monitor: Dict[str, int] = {}
+        self.to_monitor: Dict[Container, int] = {}
 
         if platform is None:
             self.platform = JobHelper.get_platform(target_exe)
@@ -233,61 +233,10 @@ class JobHelper:
         }
         self.wait_for_running = wait_for_running
 
-    def check_current_job(self) -> Job:
-        job = self.onefuzz.jobs.get(self.job.job_id)
-        if job.state in ["stopped", "stopping"]:
-            raise StoppedEarly("job unexpectedly stopped early")
-
-        errors = []
-        for task in self.onefuzz.tasks.list(job_id=self.job.job_id):
-            if task.state in ["stopped", "stopping"]:
-                if task.error:
-                    errors.append("%s: %s" % (task.config.task.type, task.error))
-                else:
-                    errors.append("%s" % task.config.task.type)
-
-        if errors:
-            raise StoppedEarly("tasks stopped unexpectedly.\n%s" % "\n".join(errors))
-        return job
-
-    def get_waiting(self) -> List[str]:
-        tasks = self.onefuzz.tasks.list(job_id=self.job.job_id)
-        waiting = [
-            "%s:%s" % (x.config.task.type.name, x.state.name)
-            for x in tasks
-            if x.state not in TaskState.has_started()
-        ]
-        return waiting
-
-    def is_running(self) -> Tuple[bool, str, Any]:
-        waiting = self.get_waiting()
-        return (not waiting, "waiting on: %s" % ", ".join(sorted(waiting)), None)
-
-    def has_files(self) -> Tuple[bool, str, Any]:
-        self.check_current_job()
-
-        new = {
-            x: len(self.onefuzz.containers.files.list(x).files)
-            for x in self.to_monitor.keys()
-        }
-
-        for container in new:
-            if new[container] > self.to_monitor[container]:
-                del self.to_monitor[container]
-        return (
-            not self.to_monitor,
-            "waiting for new files: %s" % ", ".join(self.to_monitor.keys()),
-            None,
-        )
-
     def wait(self) -> None:
-        if self.wait_for_running:
-            wait(self.is_running)
-            self.logger.info("tasks started")
-
-        if self.to_monitor:
-            wait(self.has_files)
-            self.logger.info("new files found")
+        JobMonitor(self.onefuzz, self.job).wait(
+            wait_for_running=self.wait_for_running, wait_for_files=self.to_monitor
+        )
 
     def target_exe_blob_name(
         self, target_exe: File, setup_dir: Optional[Directory]
